@@ -280,10 +280,13 @@ class R3sponse(object):
 				elif value in ["True", "true"]: value = True
 				elif value in ["None", "none", "null", "nan"]: value = None
 				else:
-					try: 
-						int(value)
-						value = int(value)
-					except: a=1
+					if isinstance(value, str):
+						if "." in str(value):
+							try: value = float(value)
+							except: a=1
+						else:
+							try: value = int(value)
+							except: a=1
 				self[key] = value
 		# clean default values.
 		def clean(self):
